SUB_API: float = 9.0  # redvox-api-1000 -> build_protos.sh -> insert_sub_api.py on 2020-09-14 20:48:24.787143

# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: src/redvox_api_m/redvox_api_m.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='src/redvox_api_m/redvox_api_m.proto',
  package='redvox_api_m',
  syntax='proto3',
  serialized_options=b'\n\016io.redvox.apis',
  serialized_pb=b'\n#src/redvox_api_m/redvox_api_m.proto\x12\x0credvox_api_m\"\xb8o\n\rRedvoxPacketM\x12\x0b\n\x03\x61pi\x18\x01 \x01(\x02\x12\x0f\n\x07sub_api\x18\x02 \x01(\x02\x12K\n\x13station_information\x18\x03 \x01(\x0b\x32..redvox_api_m.RedvoxPacketM.StationInformation\x12I\n\x12timing_information\x18\x04 \x01(\x0b\x32-.redvox_api_m.RedvoxPacketM.TimingInformation\x12\x34\n\x07sensors\x18\x05 \x01(\x0b\x32#.redvox_api_m.RedvoxPacketM.Sensors\x12>\n\revent_streams\x18\x06 \x03(\x0b\x32\'.redvox_api_m.RedvoxPacketM.EventStream\x12;\n\x08metadata\x18\x07 \x03(\x0b\x32).redvox_api_m.RedvoxPacketM.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xd8 \n\x12StationInformation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x61uth_id\x18\x04 \x01(\t\x12\x0c\n\x04make\x18\x05 \x01(\t\x12\r\n\x05model\x18\x06 \x01(\t\x12\x41\n\x02os\x18\x07 \x01(\x0e\x32\x35.redvox_api_m.RedvoxPacketM.StationInformation.OsType\x12\x12\n\nos_version\x18\x08 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\t \x01(\t\x12\x12\n\nis_private\x18\n \x01(\x08\x12P\n\x0c\x61pp_settings\x18\x0b \x01(\x0b\x32:.redvox_api_m.RedvoxPacketM.StationInformation.AppSettings\x12V\n\x0fstation_metrics\x18\x0c \x01(\x0b\x32=.redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics\x12P\n\x0cservice_urls\x18\r \x01(\x0b\x32:.redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls\x12N\n\x08metadata\x18\x0e \x03(\x0b\x32<.redvox_api_m.RedvoxPacketM.StationInformation.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xe1\x01\n\x0bServiceUrls\x12\x13\n\x0b\x61uth_server\x18\x01 \x01(\t\x12\x14\n\x0csynch_server\x18\x02 \x01(\t\x12\x1a\n\x12\x61\x63quisition_server\x18\x03 \x01(\t\x12Z\n\x08metadata\x18\x04 \x03(\x0b\x32H.redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x8a\x0b\n\x0eStationMetrics\x12=\n\ntimestamps\x18\x01 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12_\n\x0cnetwork_type\x18\x02 \x03(\x0e\x32I.redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.NetworkType\x12j\n\x12\x63\x65ll_service_state\x18\x03 \x03(\x0e\x32N.redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.CellServiceState\x12\x43\n\x10network_strength\x18\x04 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12>\n\x0btemperature\x18\x05 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12:\n\x07\x62\x61ttery\x18\x06 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12\x42\n\x0f\x62\x61ttery_current\x18\x07 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12@\n\ravailable_ram\x18\x08 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12\x41\n\x0e\x61vailable_disk\x18\t \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12\x42\n\x0f\x63pu_utilization\x18\n \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12]\n\x0bpower_state\x18\x0b \x03(\x0e\x32H.redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.PowerState\x12\x62\n\x0ewifi_wake_lock\x18\x0c \x03(\x0e\x32J.redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.WifiWakeLock\x12]\n\x08metadata\x18\r \x03(\x0b\x32K.redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x0bNetworkType\x12\x13\n\x0fUNKNOWN_NETWORK\x10\x00\x12\x0e\n\nNO_NETWORK\x10\x01\x12\x08\n\x04WIFI\x10\x02\x12\x0c\n\x08\x43\x45LLULAR\x10\x03\x12\t\n\x05WIRED\x10\x04\"C\n\x0cWifiWakeLock\x12\x08\n\x04NONE\x10\x00\x12\r\n\tHIGH_PERF\x10\x01\x12\x0f\n\x0bLOW_LATENCY\x10\x02\x12\t\n\x05OTHER\x10\x03\"^\n\x10\x43\x65llServiceState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tEMERGENCY\x10\x01\x12\x0b\n\x07NOMINAL\x10\x02\x12\x12\n\x0eOUT_OF_SERVICE\x10\x03\x12\r\n\tPOWER_OFF\x10\x04\"O\n\nPowerState\x12\x17\n\x13UNKNOWN_POWER_STATE\x10\x00\x12\r\n\tUNPLUGGED\x10\x01\x12\x0c\n\x08\x43HARGING\x10\x02\x12\x0b\n\x07\x43HARGED\x10\x03\x1a\xa5\x0e\n\x0b\x41ppSettings\x12i\n\x13\x61udio_sampling_rate\x18\x01 \x01(\x0e\x32L.redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.AudioSamplingRate\x12\x1a\n\x12samples_per_window\x18\x02 \x01(\x02\x12i\n\x13\x61udio_source_tuning\x18\x03 \x01(\x0e\x32L.redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.AudioSourceTuning\x12h\n\x18\x61\x64\x64itional_input_sensors\x18\x04 \x03(\x0e\x32\x46.redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.InputSensor\x12\x1c\n\x14\x61utomatically_record\x18\x05 \x01(\x08\x12\x1a\n\x12launch_at_power_up\x18\x06 \x01(\x08\x12\x12\n\nstation_id\x18\x07 \x01(\t\x12\x1b\n\x13station_description\x18\x08 \x01(\t\x12\x16\n\x0epush_to_server\x18\t \x01(\x08\x12\x1f\n\x17publish_data_as_private\x18\n \x01(\x08\x12\x1b\n\x13scramble_audio_data\x18\x0b \x01(\x08\x12\x18\n\x10provide_backfill\x18\x0c \x01(\x08\x12\x1f\n\x17remove_sensor_dc_offset\x18\r \x01(\x08\x12Z\n\x0b\x66\x66t_overlap\x18\x0e \x01(\x0e\x32\x45.redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.FftOverlap\x12#\n\x1buse_custom_time_sync_server\x18\x0f \x01(\x08\x12\x1c\n\x14time_sync_server_url\x18\x10 \x01(\t\x12\x1e\n\x16use_custom_data_server\x18\x11 \x01(\x08\x12\x17\n\x0f\x64\x61ta_server_url\x18\x12 \x01(\t\x12\x1e\n\x16use_custom_auth_server\x18\x13 \x01(\x08\x12\x17\n\x0f\x61uth_server_url\x18\x14 \x01(\t\x12\x1e\n\x16\x61uto_delete_data_files\x18\x15 \x01(\x08\x12\x1f\n\x17storage_space_allowance\x18\x16 \x01(\x02\x12$\n\x1cuse_sd_card_for_data_storage\x18\x17 \x01(\x08\x12\x1d\n\x15use_location_services\x18\x18 \x01(\x08\x12\x14\n\x0cuse_latitude\x18\x19 \x01(\x01\x12\x15\n\ruse_longitude\x18\x1a \x01(\x01\x12\x14\n\x0cuse_altitude\x18\x1b \x01(\x02\x12Z\n\x08metadata\x18\x1c \x03(\x0b\x32H.redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\nFftOverlap\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nPERCENT_25\x10\x01\x12\x0e\n\nPERCENT_50\x10\x02\x12\x0e\n\nPERCENT_75\x10\x03\"n\n\x11\x41udioSamplingRate\x12\x19\n\x15UNKNOWN_SAMPLING_RATE\x10\x00\x12\t\n\x05HZ_80\x10\x01\x12\n\n\x06HZ_800\x10\x02\x12\x0b\n\x07HZ_8000\x10\x03\x12\x0c\n\x08HZ_16000\x10\x04\x12\x0c\n\x08HZ_48000\x10\x05\"f\n\x11\x41udioSourceTuning\x12\x12\n\x0eUNKNOWN_TUNING\x10\x00\x12\x15\n\x11INFRASOUND_TUNING\x10\x01\x12\x14\n\x10LOW_AUDIO_TUNING\x10\x02\x12\x10\n\x0c\x41UDIO_TUNING\x10\x03\"\xb3\x02\n\x0bInputSensor\x12\x12\n\x0eUNKNOWN_SENSOR\x10\x00\x12\x11\n\rACCELEROMETER\x10\x01\x12\x17\n\x13\x41MBIENT_TEMPERATURE\x10\x02\x12\t\n\x05\x41UDIO\x10\x03\x12\x14\n\x10\x43OMPRESSED_AUDIO\x10\x04\x12\x0b\n\x07GRAVITY\x10\x05\x12\r\n\tGYROSCOPE\x10\x06\x12\t\n\x05IMAGE\x10\x07\x12\t\n\x05LIGHT\x10\x08\x12\x17\n\x13LINEAR_ACCELERATION\x10\t\x12\x0c\n\x08LOCATION\x10\n\x12\x10\n\x0cMAGNETOMETER\x10\x0b\x12\x0f\n\x0bORIENTATION\x10\x0c\x12\x0c\n\x08PRESSURE\x10\r\x12\r\n\tPROXIMITY\x10\x0e\x12\x15\n\x11RELATIVE_HUMIDITY\x10\x0f\x12\x13\n\x0fROTATION_VECTOR\x10\x10\"O\n\x06OsType\x12\x0e\n\nUNKNOWN_OS\x10\x00\x12\x0b\n\x07\x41NDROID\x10\x01\x12\x07\n\x03IOS\x10\x02\x12\x07\n\x03OSX\x10\x03\x12\t\n\x05LINUX\x10\x04\x12\x0b\n\x07WINDOWS\x10\x05\x1a\xc0\x07\n\x11TimingInformation\x12!\n\x19packet_start_os_timestamp\x18\x01 \x01(\x01\x12#\n\x1bpacket_start_mach_timestamp\x18\x02 \x01(\x01\x12\x1f\n\x17packet_end_os_timestamp\x18\x03 \x01(\x01\x12!\n\x19packet_end_mach_timestamp\x18\x04 \x01(\x01\x12,\n$server_acquisition_arrival_timestamp\x18\x05 \x01(\x01\x12 \n\x18\x61pp_start_mach_timestamp\x18\x06 \x01(\x01\x12T\n\x0fsynch_exchanges\x18\x07 \x03(\x0b\x32;.redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange\x12\x14\n\x0c\x62\x65st_latency\x18\x08 \x01(\x02\x12\x13\n\x0b\x62\x65st_offset\x18\t \x01(\x02\x12\r\n\x05score\x18\n \x01(\x02\x12U\n\x0cscore_method\x18\x0b \x01(\x0e\x32?.redvox_api_m.RedvoxPacketM.TimingInformation.TimingScoreMethod\x12.\n\x04unit\x18\x0c \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12M\n\x08metadata\x18\r \x03(\x0b\x32;.redvox_api_m.RedvoxPacketM.TimingInformation.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x95\x02\n\rSynchExchange\x12\n\n\x02\x61\x31\x18\x01 \x01(\x01\x12\n\n\x02\x61\x32\x18\x02 \x01(\x01\x12\n\n\x02\x61\x33\x18\x03 \x01(\x01\x12\n\n\x02\x62\x31\x18\x04 \x01(\x01\x12\n\n\x02\x62\x32\x18\x05 \x01(\x01\x12\n\n\x02\x62\x33\x18\x06 \x01(\x01\x12.\n\x04unit\x18\x07 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12[\n\x08metadata\x18\x08 \x03(\x0b\x32I.redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\" \n\x11TimingScoreMethod\x12\x0b\n\x07UNKNOWN\x10\x00\x1a\xed/\n\x07Sensors\x12>\n\raccelerometer\x18\x01 \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12G\n\x13\x61mbient_temperature\x18\x02 \x01(\x0b\x32*.redvox_api_m.RedvoxPacketM.Sensors.Single\x12\x38\n\x05\x61udio\x18\x03 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.Sensors.Audio\x12M\n\x10\x63ompressed_audio\x18\x04 \x01(\x0b\x32\x33.redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio\x12\x38\n\x07gravity\x18\x05 \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12:\n\tgyroscope\x18\x06 \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12\x38\n\x05image\x18\x07 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.Sensors.Image\x12\x39\n\x05light\x18\x08 \x01(\x0b\x32*.redvox_api_m.RedvoxPacketM.Sensors.Single\x12\x44\n\x13linear_acceleration\x18\t \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12>\n\x08location\x18\n \x01(\x0b\x32,.redvox_api_m.RedvoxPacketM.Sensors.Location\x12=\n\x0cmagnetometer\x18\x0b \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12<\n\x0borientation\x18\x0c \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12<\n\x08pressure\x18\r \x01(\x0b\x32*.redvox_api_m.RedvoxPacketM.Sensors.Single\x12=\n\tproximity\x18\x0e \x01(\x0b\x32*.redvox_api_m.RedvoxPacketM.Sensors.Single\x12\x45\n\x11relative_humidity\x18\x0f \x01(\x0b\x32*.redvox_api_m.RedvoxPacketM.Sensors.Single\x12@\n\x0frotation_vector\x18\x10 \x01(\x0b\x32\'.redvox_api_m.RedvoxPacketM.Sensors.Xyz\x12\x43\n\x08metadata\x18\x11 \x03(\x0b\x32\x31.redvox_api_m.RedvoxPacketM.Sensors.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xd3\x02\n\x05\x41udio\x12\x1a\n\x12sensor_description\x18\x01 \x01(\t\x12\x1e\n\x16\x66irst_sample_timestamp\x18\x02 \x01(\x01\x12\x13\n\x0bsample_rate\x18\x03 \x01(\x02\x12\x19\n\x11\x62its_of_precision\x18\x04 \x01(\x02\x12\x14\n\x0cis_scrambled\x18\x05 \x01(\x08\x12\x10\n\x08\x65ncoding\x18\x06 \x01(\t\x12:\n\x07samples\x18\x07 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12I\n\x08metadata\x18\x08 \x03(\x0b\x32\x37.redvox_api_m.RedvoxPacketM.Sensors.Audio.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x8d\x03\n\x0f\x43ompressedAudio\x12\x1a\n\x12sensor_description\x18\x01 \x01(\t\x12\x1e\n\x16\x66irst_sample_timestamp\x18\x02 \x01(\x01\x12\x13\n\x0bsample_rate\x18\x03 \x01(\x02\x12\x14\n\x0cis_scrambled\x18\x04 \x01(\x08\x12\x13\n\x0b\x61udio_bytes\x18\x05 \x01(\x0c\x12S\n\x0b\x61udio_codec\x18\x06 \x01(\x0e\x32>.redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.AudioCodec\x12S\n\x08metadata\x18\x07 \x03(\x0b\x32\x41.redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"#\n\nAudioCodec\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x46LAC\x10\x01\x1a\x9c\x02\n\x06Single\x12\x1a\n\x12sensor_description\x18\x01 \x01(\t\x12=\n\ntimestamps\x18\x02 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12:\n\x07samples\x18\x03 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12J\n\x08metadata\x18\x04 \x03(\x0b\x32\x38.redvox_api_m.RedvoxPacketM.Sensors.Single.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xd6\x18\n\x08Location\x12\x1a\n\x12sensor_description\x18\x01 \x01(\t\x12=\n\ntimestamps\x18\x02 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12\x41\n\x0etimestamps_gps\x18\x03 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12I\n\x10latitude_samples\x18\x04 \x01(\x0b\x32/.redvox_api_m.RedvoxPacketM.DoubleSamplePayload\x12J\n\x11longitude_samples\x18\x05 \x01(\x0b\x32/.redvox_api_m.RedvoxPacketM.DoubleSamplePayload\x12\x43\n\x10\x61ltitude_samples\x18\x06 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12@\n\rspeed_samples\x18\x07 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12\x42\n\x0f\x62\x65\x61ring_samples\x18\x08 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12N\n\x1bhorizontal_accuracy_samples\x18\t \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12L\n\x19vertical_accuracy_samples\x18\n \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12I\n\x16speed_accuracy_samples\x18\x0b \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12K\n\x18\x62\x65\x61ring_accuracy_samples\x18\x0c \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12U\n\x12last_best_location\x18\r \x01(\x0b\x32\x39.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation\x12X\n\x15overall_best_location\x18\x0e \x01(\x0b\x32\x39.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation\x12$\n\x1clocation_permissions_granted\x18\x0f \x01(\x08\x12#\n\x1blocation_services_requested\x18\x10 \x01(\x08\x12!\n\x19location_services_enabled\x18\x11 \x01(\x08\x12Y\n\x12location_providers\x18\x12 \x03(\x0e\x32=.redvox_api_m.RedvoxPacketM.Sensors.Location.LocationProvider\x12L\n\x08metadata\x18\x13 \x03(\x0b\x32:.redvox_api_m.RedvoxPacketM.Sensors.Location.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xcf\r\n\x0c\x42\x65stLocation\x12m\n\x1clatitude_longitude_timestamp\x18\x01 \x01(\x0b\x32G.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp\x12\x63\n\x12\x61ltitude_timestamp\x18\x02 \x01(\x0b\x32G.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp\x12`\n\x0fspeed_timestamp\x18\x03 \x01(\x0b\x32G.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp\x12\x62\n\x11\x62\x65\x61ring_timestamp\x18\x04 \x01(\x0b\x32G.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp\x12\x41\n\x17latitude_longitude_unit\x18\x05 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x37\n\raltitude_unit\x18\x06 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x34\n\nspeed_unit\x18\x07 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x36\n\x0c\x62\x65\x61ring_unit\x18\x08 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12@\n\x16vertical_accuracy_unit\x18\t \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x42\n\x18horizontal_accuracy_unit\x18\n \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12=\n\x13speed_accuracy_unit\x18\x0b \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12?\n\x15\x62\x65\x61ring_accuracy_unit\x18\x0c \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x10\n\x08latitude\x18\r \x01(\x01\x12\x11\n\tlongitude\x18\x0e \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x0f \x01(\x02\x12\r\n\x05speed\x18\x10 \x01(\x02\x12\x0f\n\x07\x62\x65\x61ring\x18\x11 \x01(\x02\x12\x19\n\x11vertical_accuracy\x18\x12 \x01(\x02\x12\x1b\n\x13horizontal_accuracy\x18\x13 \x01(\x02\x12\x16\n\x0espeed_accuracy\x18\x14 \x01(\x02\x12\x18\n\x10\x62\x65\x61ring_accuracy\x18\x15 \x01(\x02\x12\r\n\x05score\x18\x16 \x01(\x02\x12]\n\x06method\x18\x17 \x01(\x0e\x32M.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.LocationScoreMethod\x12X\n\x11location_provider\x18\x18 \x01(\x0e\x32=.redvox_api_m.RedvoxPacketM.Sensors.Location.LocationProvider\x12Y\n\x08metadata\x18\x19 \x03(\x0b\x32G.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xf4\x01\n\rBestTimestamp\x12.\n\x04unit\x18\x01 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x0c\n\x04mach\x18\x02 \x01(\x01\x12\x0b\n\x03gps\x18\x03 \x01(\x01\x12g\n\x08metadata\x18\x04 \x03(\x0b\x32U.redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x13LocationScoreMethod\x12\x12\n\x0eUNKNOWN_METHOD\x10\x00\"I\n\x10LocationProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x08\n\x04USER\x10\x02\x12\x07\n\x03GPS\x10\x03\x12\x0b\n\x07NETWORK\x10\x04\x1a\x94\x03\n\x03Xyz\x12\x1a\n\x12sensor_description\x18\x01 \x01(\t\x12=\n\ntimestamps\x18\x02 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12<\n\tx_samples\x18\x03 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12<\n\ty_samples\x18\x04 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12<\n\tz_samples\x18\x05 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.SamplePayload\x12G\n\x08metadata\x18\x06 \x03(\x0b\x32\x35.redvox_api_m.RedvoxPacketM.Sensors.Xyz.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xf0\x02\n\x05Image\x12\x1a\n\x12sensor_description\x18\x01 \x01(\t\x12=\n\ntimestamps\x18\x02 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12\x0f\n\x07samples\x18\x03 \x03(\x0c\x12I\n\x0bimage_codec\x18\x04 \x01(\x0e\x32\x34.redvox_api_m.RedvoxPacketM.Sensors.Image.ImageCodec\x12I\n\x08metadata\x18\x05 \x03(\x0b\x32\x37.redvox_api_m.RedvoxPacketM.Sensors.Image.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"4\n\nImageCodec\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03PNG\x10\x01\x12\x07\n\x03JPG\x10\x02\x12\x07\n\x03\x42MP\x10\x03\x1a\xf2\x07\n\x0b\x45ventStream\x12\x0c\n\x04name\x18\x01 \x01(\t\x12=\n\ntimestamps\x18\x02 \x01(\x0b\x32).redvox_api_m.RedvoxPacketM.TimingPayload\x12=\n\x06\x65vents\x18\x03 \x03(\x0b\x32-.redvox_api_m.RedvoxPacketM.EventStream.Event\x12G\n\x08metadata\x18\x04 \x03(\x0b\x32\x35.redvox_api_m.RedvoxPacketM.EventStream.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xdc\x05\n\x05\x45vent\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12X\n\x0estring_payload\x18\x02 \x03(\x0b\x32@.redvox_api_m.RedvoxPacketM.EventStream.Event.StringPayloadEntry\x12Z\n\x0fnumeric_payload\x18\x03 \x03(\x0b\x32\x41.redvox_api_m.RedvoxPacketM.EventStream.Event.NumericPayloadEntry\x12Z\n\x0f\x62oolean_payload\x18\x04 \x03(\x0b\x32\x41.redvox_api_m.RedvoxPacketM.EventStream.Event.BooleanPayloadEntry\x12T\n\x0c\x62yte_payload\x18\x05 \x03(\x0b\x32>.redvox_api_m.RedvoxPacketM.EventStream.Event.BytePayloadEntry\x12M\n\x08metadata\x18\x06 \x03(\x0b\x32;.redvox_api_m.RedvoxPacketM.EventStream.Event.MetadataEntry\x1a\x34\n\x12StringPayloadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13NumericPayloadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\x35\n\x13\x42ooleanPayloadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x32\n\x10\x42ytePayloadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x94\x02\n\rSamplePayload\x12.\n\x04unit\x18\x01 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x0e\n\x06values\x18\x02 \x03(\x02\x12G\n\x10value_statistics\x18\x03 \x01(\x0b\x32-.redvox_api_m.RedvoxPacketM.SummaryStatistics\x12I\n\x08metadata\x18\x04 \x03(\x0b\x32\x37.redvox_api_m.RedvoxPacketM.SamplePayload.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xa0\x02\n\x13\x44oubleSamplePayload\x12.\n\x04unit\x18\x01 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x0e\n\x06values\x18\x02 \x03(\x01\x12G\n\x10value_statistics\x18\x03 \x01(\x0b\x32-.redvox_api_m.RedvoxPacketM.SummaryStatistics\x12O\n\x08metadata\x18\x04 \x03(\x0b\x32=.redvox_api_m.RedvoxPacketM.DoubleSamplePayload.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xd1\x02\n\rTimingPayload\x12.\n\x04unit\x18\x01 \x01(\x0e\x32 .redvox_api_m.RedvoxPacketM.Unit\x12\x12\n\ntimestamps\x18\x02 \x03(\x01\x12K\n\x14timestamp_statistics\x18\x03 \x01(\x0b\x32-.redvox_api_m.RedvoxPacketM.SummaryStatistics\x12\x18\n\x10mean_sample_rate\x18\x04 \x01(\x02\x12\x19\n\x11stdev_sample_rate\x18\x05 \x01(\x02\x12I\n\x08metadata\x18\x06 \x03(\x0b\x32\x37.redvox_api_m.RedvoxPacketM.TimingPayload.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xf5\x01\n\x11SummaryStatistics\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x0c\n\x04mean\x18\x02 \x01(\x01\x12\x1a\n\x12standard_deviation\x18\x03 \x01(\x01\x12\x0b\n\x03min\x18\x04 \x01(\x01\x12\x0b\n\x03max\x18\x05 \x01(\x01\x12\r\n\x05range\x18\x06 \x01(\x01\x12M\n\x08metadata\x18\x07 \x03(\x0b\x32;.redvox_api_m.RedvoxPacketM.SummaryStatistics.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x03\n\x04Unit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x1d\n\x19METERS_PER_SECOND_SQUARED\x10\x01\x12\x0e\n\nKILOPASCAL\x10\x02\x12\x16\n\x12RADIANS_PER_SECOND\x10\x03\x12\x13\n\x0f\x44\x45\x43IMAL_DEGREES\x10\x04\x12\n\n\x06METERS\x10\x05\x12\x15\n\x11METERS_PER_SECOND\x10\x06\x12\x0e\n\nMICROTESLA\x10\x07\x12\x19\n\x15LSB_PLUS_MINUS_COUNTS\x10\x08\x12!\n\x1dMICROSECONDS_SINCE_UNIX_EPOCH\x10\t\x12\x0b\n\x07\x44\x45\x43IBEL\x10\n\x12\x13\n\x0f\x44\x45GREES_CELSIUS\x10\x0b\x12\x08\n\x04\x42YTE\x10\x0c\x12\x0e\n\nPERCENTAGE\x10\r\x12\x0b\n\x07RADIANS\x10\x0e\x12\x10\n\x0cMICROAMPERES\x10\x0f\x12\x0f\n\x0b\x43\x45NTIMETERS\x10\x10\x12\x15\n\x11NORMALIZED_COUNTS\x10\x11\x12\x07\n\x03LUX\x10\x12\x12\x0c\n\x08UNITLESS\x10\x13\x12\x07\n\x03PCM\x10\x14\"\xac\x01\n\x16\x45ncryptedRedvoxPacketM\x12\x0e\n\x06header\x18\x01 \x01(\x0c\x12\x0e\n\x06packet\x18\x02 \x01(\x0c\x1ar\n\x06Header\x12\x12\n\nstation_id\x18\x01 \x01(\t\x12\x14\n\x0cstation_uuid\x18\x02 \x01(\t\x12\x12\n\nauth_token\x18\x03 \x01(\t\x12\x16\n\x0e\x66irebase_token\x18\x04 \x01(\t\x12\x12\n\nauth_email\x18\x05 \x01(\t\"\x89\x01\n\x12\x41\x63quisitionRequest\x12\x12\n\nauth_token\x18\x01 \x01(\t\x12\x16\n\x0e\x66irebase_token\x18\x02 \x01(\t\x12\x10\n\x08\x63hecksum\x18\x03 \x01(\x03\x12\x14\n\x0cis_encrypted\x18\x04 \x01(\x08\x12\x0f\n\x07payload\x18\x05 \x01(\x0c\x12\x0e\n\x06seq_id\x18\x06 \x01(\x03\"\xf5\x01\n\x13\x41\x63quisitionResponse\x12\x45\n\rresponse_type\x18\x01 \x01(\x0e\x32..redvox_api_m.AcquisitionResponse.ResponseType\x12\x10\n\x08\x63hecksum\x18\x02 \x01(\x03\x12\x0f\n\x07\x64\x65tails\x18\x03 \x01(\t\x12\x0e\n\x06resend\x18\x04 \x01(\x08\x12\x0e\n\x06seq_id\x18\x05 \x01(\x03\"T\n\x0cResponseType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0e\n\nAUTH_ERROR\x10\x02\x12\x0e\n\nDATA_ERROR\x10\x03\x12\x0f\n\x0bOTHER_ERROR\x10\x04\"\\\n\x0cSynchRequest\x12\x12\n\nstation_id\x18\x01 \x01(\t\x12\x14\n\x0cstation_uuid\x18\x02 \x01(\t\x12\x0e\n\x06seq_id\x18\x03 \x01(\r\x12\x12\n\nsub_seq_id\x18\x04 \x01(\r\"\x85\x01\n\rSynchResponse\x12\x12\n\nstation_id\x18\x01 \x01(\t\x12\x14\n\x0cstation_uuid\x18\x02 \x01(\t\x12\x0e\n\x06seq_id\x18\x03 \x01(\r\x12\x12\n\nsub_seq_id\x18\x04 \x01(\r\x12\x12\n\nrecv_ts_us\x18\x05 \x01(\x04\x12\x12\n\nsend_ts_us\x18\x06 \x01(\x04\x42\x10\n\x0eio.redvox.apisb\x06proto3'
)



_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_NETWORKTYPE = _descriptor.EnumDescriptor(
  name='NetworkType',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.NetworkType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_NETWORK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_NETWORK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WIFI', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CELLULAR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WIRED', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2422,
  serialized_end=2507,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_NETWORKTYPE)

_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_WIFIWAKELOCK = _descriptor.EnumDescriptor(
  name='WifiWakeLock',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.WifiWakeLock',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HIGH_PERF', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOW_LATENCY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2509,
  serialized_end=2576,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_WIFIWAKELOCK)

_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_CELLSERVICESTATE = _descriptor.EnumDescriptor(
  name='CellServiceState',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.CellServiceState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOMINAL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUT_OF_SERVICE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POWER_OFF', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2578,
  serialized_end=2672,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_CELLSERVICESTATE)

_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_POWERSTATE = _descriptor.EnumDescriptor(
  name='PowerState',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.PowerState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_POWER_STATE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNPLUGGED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHARGING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHARGED', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2674,
  serialized_end=2753,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_POWERSTATE)

_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_FFTOVERLAP = _descriptor.EnumDescriptor(
  name='FftOverlap',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.FftOverlap',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERCENT_25', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERCENT_50', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERCENT_75', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3986,
  serialized_end=4059,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_FFTOVERLAP)

_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSAMPLINGRATE = _descriptor.EnumDescriptor(
  name='AudioSamplingRate',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.AudioSamplingRate',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_SAMPLING_RATE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HZ_80', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HZ_800', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HZ_8000', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HZ_16000', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HZ_48000', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4061,
  serialized_end=4171,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSAMPLINGRATE)

_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSOURCETUNING = _descriptor.EnumDescriptor(
  name='AudioSourceTuning',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.AudioSourceTuning',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_TUNING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFRASOUND_TUNING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOW_AUDIO_TUNING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUDIO_TUNING', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4173,
  serialized_end=4275,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSOURCETUNING)

_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_INPUTSENSOR = _descriptor.EnumDescriptor(
  name='InputSensor',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.InputSensor',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_SENSOR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCELEROMETER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AMBIENT_TEMPERATURE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUDIO', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSED_AUDIO', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GRAVITY', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GYROSCOPE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIGHT', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINEAR_ACCELERATION', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAGNETOMETER', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORIENTATION', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRESSURE', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROXIMITY', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RELATIVE_HUMIDITY', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROTATION_VECTOR', index=16, number=16,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4278,
  serialized_end=4585,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_INPUTSENSOR)

_REDVOXPACKETM_STATIONINFORMATION_OSTYPE = _descriptor.EnumDescriptor(
  name='OsType',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.OsType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_OS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANDROID', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IOS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OSX', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINUX', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WINDOWS', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4587,
  serialized_end=4666,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_STATIONINFORMATION_OSTYPE)

_REDVOXPACKETM_TIMINGINFORMATION_TIMINGSCOREMETHOD = _descriptor.EnumDescriptor(
  name='TimingScoreMethod',
  full_name='redvox_api_m.RedvoxPacketM.TimingInformation.TimingScoreMethod',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5597,
  serialized_end=5629,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_TIMINGINFORMATION_TIMINGSCOREMETHOD)

_REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_AUDIOCODEC = _descriptor.EnumDescriptor(
  name='AudioCodec',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.AudioCodec',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLAC', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7496,
  serialized_end=7531,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_AUDIOCODEC)

_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_LOCATIONSCOREMETHOD = _descriptor.EnumDescriptor(
  name='LocationScoreMethod',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.LocationScoreMethod',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_METHOD', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10863,
  serialized_end=10904,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_LOCATIONSCOREMETHOD)

_REDVOXPACKETM_SENSORS_LOCATION_LOCATIONPROVIDER = _descriptor.EnumDescriptor(
  name='LocationProvider',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.LocationProvider',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GPS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10906,
  serialized_end=10979,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_SENSORS_LOCATION_LOCATIONPROVIDER)

_REDVOXPACKETM_SENSORS_IMAGE_IMAGECODEC = _descriptor.EnumDescriptor(
  name='ImageCodec',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Image.ImageCodec',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PNG', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JPG', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BMP', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11705,
  serialized_end=11757,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_SENSORS_IMAGE_IMAGECODEC)

_REDVOXPACKETM_UNIT = _descriptor.EnumDescriptor(
  name='Unit',
  full_name='redvox_api_m.RedvoxPacketM.Unit',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='METERS_PER_SECOND_SQUARED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KILOPASCAL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RADIANS_PER_SECOND', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECIMAL_DEGREES', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='METERS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='METERS_PER_SECOND', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MICROTESLA', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LSB_PLUS_MINUS_COUNTS', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MICROSECONDS_SINCE_UNIX_EPOCH', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECIBEL', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEGREES_CELSIUS', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BYTE', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERCENTAGE', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RADIANS', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MICROAMPERES', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CENTIMETERS', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NORMALIZED_COUNTS', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LUX', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNITLESS', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PCM', index=20, number=20,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13931,
  serialized_end=14318,
)
_sym_db.RegisterEnumDescriptor(_REDVOXPACKETM_UNIT)

_ACQUISITIONRESPONSE_RESPONSETYPE = _descriptor.EnumDescriptor(
  name='ResponseType',
  full_name='redvox_api_m.AcquisitionResponse.ResponseType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTH_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATA_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTHER_ERROR', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14797,
  serialized_end=14881,
)
_sym_db.RegisterEnumDescriptor(_ACQUISITIONRESPONSE_RESPONSETYPE)


_REDVOXPACKETM_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_STATIONINFORMATION_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.StationInformation.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.StationInformation.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS = _descriptor.Descriptor(
  name='ServiceUrls',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_server', full_name='redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls.auth_server', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='synch_server', full_name='redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls.synch_server', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acquisition_server', full_name='redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls.acquisition_server', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1332,
)

_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS = _descriptor.Descriptor(
  name='StationMetrics',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.timestamps', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network_type', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.network_type', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cell_service_state', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.cell_service_state', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network_strength', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.network_strength', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.temperature', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='battery', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.battery', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='battery_current', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.battery_current', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='available_ram', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.available_ram', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='available_disk', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.available_disk', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpu_utilization', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.cpu_utilization', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='power_state', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.power_state', index=10,
      number=11, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wifi_wake_lock', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.wifi_wake_lock', index=11,
      number=12, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.metadata', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_METADATAENTRY, ],
  enum_types=[
    _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_NETWORKTYPE,
    _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_WIFIWAKELOCK,
    _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_CELLSERVICESTATE,
    _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_POWERSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1335,
  serialized_end=2753,
)

_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS = _descriptor.Descriptor(
  name='AppSettings',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_sampling_rate', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.audio_sampling_rate', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='samples_per_window', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.samples_per_window', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio_source_tuning', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.audio_source_tuning', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional_input_sensors', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.additional_input_sensors', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='automatically_record', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.automatically_record', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='launch_at_power_up', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.launch_at_power_up', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='station_id', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.station_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='station_description', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.station_description', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='push_to_server', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.push_to_server', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='publish_data_as_private', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.publish_data_as_private', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scramble_audio_data', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.scramble_audio_data', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='provide_backfill', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.provide_backfill', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove_sensor_dc_offset', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.remove_sensor_dc_offset', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fft_overlap', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.fft_overlap', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_custom_time_sync_server', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.use_custom_time_sync_server', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_sync_server_url', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.time_sync_server_url', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_custom_data_server', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.use_custom_data_server', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_server_url', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.data_server_url', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_custom_auth_server', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.use_custom_auth_server', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_server_url', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.auth_server_url', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_delete_data_files', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.auto_delete_data_files', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_space_allowance', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.storage_space_allowance', index=21,
      number=22, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_sd_card_for_data_storage', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.use_sd_card_for_data_storage', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_location_services', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.use_location_services', index=23,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_latitude', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.use_latitude', index=24,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_longitude', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.use_longitude', index=25,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_altitude', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.use_altitude', index=26,
      number=27, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.metadata', index=27,
      number=28, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_METADATAENTRY, ],
  enum_types=[
    _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_FFTOVERLAP,
    _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSAMPLINGRATE,
    _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSOURCETUNING,
    _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_INPUTSENSOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2756,
  serialized_end=4585,
)

_REDVOXPACKETM_STATIONINFORMATION = _descriptor.Descriptor(
  name='StationInformation',
  full_name='redvox_api_m.RedvoxPacketM.StationInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='redvox_api_m.RedvoxPacketM.StationInformation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='redvox_api_m.RedvoxPacketM.StationInformation.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='redvox_api_m.RedvoxPacketM.StationInformation.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_id', full_name='redvox_api_m.RedvoxPacketM.StationInformation.auth_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='make', full_name='redvox_api_m.RedvoxPacketM.StationInformation.make', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='redvox_api_m.RedvoxPacketM.StationInformation.model', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='os', full_name='redvox_api_m.RedvoxPacketM.StationInformation.os', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='os_version', full_name='redvox_api_m.RedvoxPacketM.StationInformation.os_version', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_version', full_name='redvox_api_m.RedvoxPacketM.StationInformation.app_version', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_private', full_name='redvox_api_m.RedvoxPacketM.StationInformation.is_private', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_settings', full_name='redvox_api_m.RedvoxPacketM.StationInformation.app_settings', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='station_metrics', full_name='redvox_api_m.RedvoxPacketM.StationInformation.station_metrics', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_urls', full_name='redvox_api_m.RedvoxPacketM.StationInformation.service_urls', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.StationInformation.metadata', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_STATIONINFORMATION_METADATAENTRY, _REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS, _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS, _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS, ],
  enum_types=[
    _REDVOXPACKETM_STATIONINFORMATION_OSTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=482,
  serialized_end=4666,
)

_REDVOXPACKETM_TIMINGINFORMATION_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.TimingInformation.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE = _descriptor.Descriptor(
  name='SynchExchange',
  full_name='redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='a1', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.a1', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='a2', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.a2', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='a3', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.a3', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='b1', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.b1', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='b2', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.b2', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='b3', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.b3', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.unit', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.metadata', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5318,
  serialized_end=5595,
)

_REDVOXPACKETM_TIMINGINFORMATION = _descriptor.Descriptor(
  name='TimingInformation',
  full_name='redvox_api_m.RedvoxPacketM.TimingInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packet_start_os_timestamp', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.packet_start_os_timestamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packet_start_mach_timestamp', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.packet_start_mach_timestamp', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packet_end_os_timestamp', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.packet_end_os_timestamp', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packet_end_mach_timestamp', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.packet_end_mach_timestamp', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_acquisition_arrival_timestamp', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.server_acquisition_arrival_timestamp', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_start_mach_timestamp', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.app_start_mach_timestamp', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='synch_exchanges', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.synch_exchanges', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_latency', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.best_latency', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_offset', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.best_offset', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.score', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score_method', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.score_method', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unit', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.unit', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.TimingInformation.metadata', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_TIMINGINFORMATION_METADATAENTRY, _REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE, ],
  enum_types=[
    _REDVOXPACKETM_TIMINGINFORMATION_TIMINGSCOREMETHOD,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4669,
  serialized_end=5629,
)

_REDVOXPACKETM_SENSORS_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.Sensors.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.Sensors.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_SENSORS_AUDIO_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Audio.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.Sensors.Audio.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.Sensors.Audio.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_SENSORS_AUDIO = _descriptor.Descriptor(
  name='Audio',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Audio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_description', full_name='redvox_api_m.RedvoxPacketM.Sensors.Audio.sensor_description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_sample_timestamp', full_name='redvox_api_m.RedvoxPacketM.Sensors.Audio.first_sample_timestamp', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='redvox_api_m.RedvoxPacketM.Sensors.Audio.sample_rate', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bits_of_precision', full_name='redvox_api_m.RedvoxPacketM.Sensors.Audio.bits_of_precision', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_scrambled', full_name='redvox_api_m.RedvoxPacketM.Sensors.Audio.is_scrambled', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encoding', full_name='redvox_api_m.RedvoxPacketM.Sensors.Audio.encoding', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Audio.samples', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.Sensors.Audio.metadata', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_SENSORS_AUDIO_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6792,
  serialized_end=7131,
)

_REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO = _descriptor.Descriptor(
  name='CompressedAudio',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_description', full_name='redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.sensor_description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_sample_timestamp', full_name='redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.first_sample_timestamp', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_rate', full_name='redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.sample_rate', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_scrambled', full_name='redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.is_scrambled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio_bytes', full_name='redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.audio_bytes', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio_codec', full_name='redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.audio_codec', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.metadata', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_METADATAENTRY, ],
  enum_types=[
    _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_AUDIOCODEC,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7134,
  serialized_end=7531,
)

_REDVOXPACKETM_SENSORS_SINGLE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Single.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.Sensors.Single.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.Sensors.Single.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_SENSORS_SINGLE = _descriptor.Descriptor(
  name='Single',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Single',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_description', full_name='redvox_api_m.RedvoxPacketM.Sensors.Single.sensor_description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='redvox_api_m.RedvoxPacketM.Sensors.Single.timestamps', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Single.samples', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.Sensors.Single.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_SENSORS_SINGLE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7534,
  serialized_end=7818,
)

_REDVOXPACKETM_SENSORS_LOCATION_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP = _descriptor.Descriptor(
  name='BestTimestamp',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp.unit', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mach', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp.mach', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gps', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp.gps', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10617,
  serialized_end=10861,
)

_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION = _descriptor.Descriptor(
  name='BestLocation',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude_longitude_timestamp', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.latitude_longitude_timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='altitude_timestamp', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.altitude_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed_timestamp', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.speed_timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bearing_timestamp', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.bearing_timestamp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latitude_longitude_unit', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.latitude_longitude_unit', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='altitude_unit', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.altitude_unit', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed_unit', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.speed_unit', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bearing_unit', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.bearing_unit', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_accuracy_unit', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.vertical_accuracy_unit', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='horizontal_accuracy_unit', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.horizontal_accuracy_unit', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed_accuracy_unit', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.speed_accuracy_unit', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bearing_accuracy_unit', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.bearing_accuracy_unit', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.latitude', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.longitude', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='altitude', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.altitude', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.speed', index=15,
      number=16, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bearing', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.bearing', index=16,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_accuracy', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.vertical_accuracy', index=17,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='horizontal_accuracy', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.horizontal_accuracy', index=18,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed_accuracy', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.speed_accuracy', index=19,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bearing_accuracy', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.bearing_accuracy', index=20,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.score', index=21,
      number=22, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.method', index=22,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_provider', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.location_provider', index=23,
      number=24, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.metadata', index=24,
      number=25, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_METADATAENTRY, _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP, ],
  enum_types=[
    _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_LOCATIONSCOREMETHOD,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9161,
  serialized_end=10904,
)

_REDVOXPACKETM_SENSORS_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_description', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.sensor_description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.timestamps', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamps_gps', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.timestamps_gps', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latitude_samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.latitude_samples', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude_samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.longitude_samples', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='altitude_samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.altitude_samples', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed_samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.speed_samples', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bearing_samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.bearing_samples', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='horizontal_accuracy_samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.horizontal_accuracy_samples', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_accuracy_samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.vertical_accuracy_samples', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed_accuracy_samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.speed_accuracy_samples', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bearing_accuracy_samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.bearing_accuracy_samples', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_best_location', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.last_best_location', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='overall_best_location', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.overall_best_location', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_permissions_granted', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.location_permissions_granted', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_services_requested', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.location_services_requested', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_services_enabled', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.location_services_enabled', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_providers', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.location_providers', index=17,
      number=18, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.Sensors.Location.metadata', index=18,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_SENSORS_LOCATION_METADATAENTRY, _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION, ],
  enum_types=[
    _REDVOXPACKETM_SENSORS_LOCATION_LOCATIONPROVIDER,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7821,
  serialized_end=10979,
)

_REDVOXPACKETM_SENSORS_XYZ_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Xyz.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.Sensors.Xyz.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.Sensors.Xyz.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_SENSORS_XYZ = _descriptor.Descriptor(
  name='Xyz',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Xyz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_description', full_name='redvox_api_m.RedvoxPacketM.Sensors.Xyz.sensor_description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='redvox_api_m.RedvoxPacketM.Sensors.Xyz.timestamps', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='x_samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Xyz.x_samples', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y_samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Xyz.y_samples', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='z_samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Xyz.z_samples', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.Sensors.Xyz.metadata', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_SENSORS_XYZ_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10982,
  serialized_end=11386,
)

_REDVOXPACKETM_SENSORS_IMAGE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Image.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.Sensors.Image.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.Sensors.Image.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_SENSORS_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='redvox_api_m.RedvoxPacketM.Sensors.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_description', full_name='redvox_api_m.RedvoxPacketM.Sensors.Image.sensor_description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='redvox_api_m.RedvoxPacketM.Sensors.Image.timestamps', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='samples', full_name='redvox_api_m.RedvoxPacketM.Sensors.Image.samples', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_codec', full_name='redvox_api_m.RedvoxPacketM.Sensors.Image.image_codec', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.Sensors.Image.metadata', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_SENSORS_IMAGE_METADATAENTRY, ],
  enum_types=[
    _REDVOXPACKETM_SENSORS_IMAGE_IMAGECODEC,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11389,
  serialized_end=11757,
)

_REDVOXPACKETM_SENSORS = _descriptor.Descriptor(
  name='Sensors',
  full_name='redvox_api_m.RedvoxPacketM.Sensors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accelerometer', full_name='redvox_api_m.RedvoxPacketM.Sensors.accelerometer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ambient_temperature', full_name='redvox_api_m.RedvoxPacketM.Sensors.ambient_temperature', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio', full_name='redvox_api_m.RedvoxPacketM.Sensors.audio', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressed_audio', full_name='redvox_api_m.RedvoxPacketM.Sensors.compressed_audio', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gravity', full_name='redvox_api_m.RedvoxPacketM.Sensors.gravity', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gyroscope', full_name='redvox_api_m.RedvoxPacketM.Sensors.gyroscope', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='redvox_api_m.RedvoxPacketM.Sensors.image', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='light', full_name='redvox_api_m.RedvoxPacketM.Sensors.light', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='linear_acceleration', full_name='redvox_api_m.RedvoxPacketM.Sensors.linear_acceleration', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='redvox_api_m.RedvoxPacketM.Sensors.location', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='magnetometer', full_name='redvox_api_m.RedvoxPacketM.Sensors.magnetometer', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='redvox_api_m.RedvoxPacketM.Sensors.orientation', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pressure', full_name='redvox_api_m.RedvoxPacketM.Sensors.pressure', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proximity', full_name='redvox_api_m.RedvoxPacketM.Sensors.proximity', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relative_humidity', full_name='redvox_api_m.RedvoxPacketM.Sensors.relative_humidity', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rotation_vector', full_name='redvox_api_m.RedvoxPacketM.Sensors.rotation_vector', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.Sensors.metadata', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_SENSORS_METADATAENTRY, _REDVOXPACKETM_SENSORS_AUDIO, _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO, _REDVOXPACKETM_SENSORS_SINGLE, _REDVOXPACKETM_SENSORS_LOCATION, _REDVOXPACKETM_SENSORS_XYZ, _REDVOXPACKETM_SENSORS_IMAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5632,
  serialized_end=11757,
)

_REDVOXPACKETM_EVENTSTREAM_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.EventStream.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.EventStream.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.EventStream.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_EVENTSTREAM_EVENT_STRINGPAYLOADENTRY = _descriptor.Descriptor(
  name='StringPayloadEntry',
  full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.StringPayloadEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.StringPayloadEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.StringPayloadEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12507,
  serialized_end=12559,
)

_REDVOXPACKETM_EVENTSTREAM_EVENT_NUMERICPAYLOADENTRY = _descriptor.Descriptor(
  name='NumericPayloadEntry',
  full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.NumericPayloadEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.NumericPayloadEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.NumericPayloadEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12561,
  serialized_end=12614,
)

_REDVOXPACKETM_EVENTSTREAM_EVENT_BOOLEANPAYLOADENTRY = _descriptor.Descriptor(
  name='BooleanPayloadEntry',
  full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.BooleanPayloadEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.BooleanPayloadEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.BooleanPayloadEntry.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12616,
  serialized_end=12669,
)

_REDVOXPACKETM_EVENTSTREAM_EVENT_BYTEPAYLOADENTRY = _descriptor.Descriptor(
  name='BytePayloadEntry',
  full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.BytePayloadEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.BytePayloadEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.BytePayloadEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12671,
  serialized_end=12721,
)

_REDVOXPACKETM_EVENTSTREAM_EVENT_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_EVENTSTREAM_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='redvox_api_m.RedvoxPacketM.EventStream.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_payload', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.string_payload', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numeric_payload', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.numeric_payload', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolean_payload', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.boolean_payload', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='byte_payload', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.byte_payload', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.EventStream.Event.metadata', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_EVENTSTREAM_EVENT_STRINGPAYLOADENTRY, _REDVOXPACKETM_EVENTSTREAM_EVENT_NUMERICPAYLOADENTRY, _REDVOXPACKETM_EVENTSTREAM_EVENT_BOOLEANPAYLOADENTRY, _REDVOXPACKETM_EVENTSTREAM_EVENT_BYTEPAYLOADENTRY, _REDVOXPACKETM_EVENTSTREAM_EVENT_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12038,
  serialized_end=12770,
)

_REDVOXPACKETM_EVENTSTREAM = _descriptor.Descriptor(
  name='EventStream',
  full_name='redvox_api_m.RedvoxPacketM.EventStream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='redvox_api_m.RedvoxPacketM.EventStream.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='redvox_api_m.RedvoxPacketM.EventStream.timestamps', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='events', full_name='redvox_api_m.RedvoxPacketM.EventStream.events', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.EventStream.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_EVENTSTREAM_METADATAENTRY, _REDVOXPACKETM_EVENTSTREAM_EVENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11760,
  serialized_end=12770,
)

_REDVOXPACKETM_SAMPLEPAYLOAD_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.SamplePayload.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.SamplePayload.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.SamplePayload.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_SAMPLEPAYLOAD = _descriptor.Descriptor(
  name='SamplePayload',
  full_name='redvox_api_m.RedvoxPacketM.SamplePayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit', full_name='redvox_api_m.RedvoxPacketM.SamplePayload.unit', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='redvox_api_m.RedvoxPacketM.SamplePayload.values', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_statistics', full_name='redvox_api_m.RedvoxPacketM.SamplePayload.value_statistics', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.SamplePayload.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_SAMPLEPAYLOAD_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12773,
  serialized_end=13049,
)

_REDVOXPACKETM_DOUBLESAMPLEPAYLOAD_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.DoubleSamplePayload.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.DoubleSamplePayload.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.DoubleSamplePayload.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_DOUBLESAMPLEPAYLOAD = _descriptor.Descriptor(
  name='DoubleSamplePayload',
  full_name='redvox_api_m.RedvoxPacketM.DoubleSamplePayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit', full_name='redvox_api_m.RedvoxPacketM.DoubleSamplePayload.unit', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='redvox_api_m.RedvoxPacketM.DoubleSamplePayload.values', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_statistics', full_name='redvox_api_m.RedvoxPacketM.DoubleSamplePayload.value_statistics', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.DoubleSamplePayload.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_DOUBLESAMPLEPAYLOAD_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13052,
  serialized_end=13340,
)

_REDVOXPACKETM_TIMINGPAYLOAD_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.TimingPayload.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.TimingPayload.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.TimingPayload.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_TIMINGPAYLOAD = _descriptor.Descriptor(
  name='TimingPayload',
  full_name='redvox_api_m.RedvoxPacketM.TimingPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit', full_name='redvox_api_m.RedvoxPacketM.TimingPayload.unit', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='redvox_api_m.RedvoxPacketM.TimingPayload.timestamps', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp_statistics', full_name='redvox_api_m.RedvoxPacketM.TimingPayload.timestamp_statistics', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mean_sample_rate', full_name='redvox_api_m.RedvoxPacketM.TimingPayload.mean_sample_rate', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stdev_sample_rate', full_name='redvox_api_m.RedvoxPacketM.TimingPayload.stdev_sample_rate', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.TimingPayload.metadata', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_TIMINGPAYLOAD_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13343,
  serialized_end=13680,
)

_REDVOXPACKETM_SUMMARYSTATISTICS_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='redvox_api_m.RedvoxPacketM.SummaryStatistics.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='redvox_api_m.RedvoxPacketM.SummaryStatistics.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='redvox_api_m.RedvoxPacketM.SummaryStatistics.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=479,
)

_REDVOXPACKETM_SUMMARYSTATISTICS = _descriptor.Descriptor(
  name='SummaryStatistics',
  full_name='redvox_api_m.RedvoxPacketM.SummaryStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='redvox_api_m.RedvoxPacketM.SummaryStatistics.count', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mean', full_name='redvox_api_m.RedvoxPacketM.SummaryStatistics.mean', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='standard_deviation', full_name='redvox_api_m.RedvoxPacketM.SummaryStatistics.standard_deviation', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min', full_name='redvox_api_m.RedvoxPacketM.SummaryStatistics.min', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max', full_name='redvox_api_m.RedvoxPacketM.SummaryStatistics.max', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range', full_name='redvox_api_m.RedvoxPacketM.SummaryStatistics.range', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.SummaryStatistics.metadata', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_SUMMARYSTATISTICS_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13683,
  serialized_end=13928,
)

_REDVOXPACKETM = _descriptor.Descriptor(
  name='RedvoxPacketM',
  full_name='redvox_api_m.RedvoxPacketM',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='api', full_name='redvox_api_m.RedvoxPacketM.api', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub_api', full_name='redvox_api_m.RedvoxPacketM.sub_api', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='station_information', full_name='redvox_api_m.RedvoxPacketM.station_information', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timing_information', full_name='redvox_api_m.RedvoxPacketM.timing_information', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensors', full_name='redvox_api_m.RedvoxPacketM.sensors', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event_streams', full_name='redvox_api_m.RedvoxPacketM.event_streams', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='redvox_api_m.RedvoxPacketM.metadata', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REDVOXPACKETM_METADATAENTRY, _REDVOXPACKETM_STATIONINFORMATION, _REDVOXPACKETM_TIMINGINFORMATION, _REDVOXPACKETM_SENSORS, _REDVOXPACKETM_EVENTSTREAM, _REDVOXPACKETM_SAMPLEPAYLOAD, _REDVOXPACKETM_DOUBLESAMPLEPAYLOAD, _REDVOXPACKETM_TIMINGPAYLOAD, _REDVOXPACKETM_SUMMARYSTATISTICS, ],
  enum_types=[
    _REDVOXPACKETM_UNIT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=14318,
)


_ENCRYPTEDREDVOXPACKETM_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='redvox_api_m.EncryptedRedvoxPacketM.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='station_id', full_name='redvox_api_m.EncryptedRedvoxPacketM.Header.station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='station_uuid', full_name='redvox_api_m.EncryptedRedvoxPacketM.Header.station_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_token', full_name='redvox_api_m.EncryptedRedvoxPacketM.Header.auth_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='firebase_token', full_name='redvox_api_m.EncryptedRedvoxPacketM.Header.firebase_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_email', full_name='redvox_api_m.EncryptedRedvoxPacketM.Header.auth_email', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14379,
  serialized_end=14493,
)

_ENCRYPTEDREDVOXPACKETM = _descriptor.Descriptor(
  name='EncryptedRedvoxPacketM',
  full_name='redvox_api_m.EncryptedRedvoxPacketM',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='redvox_api_m.EncryptedRedvoxPacketM.header', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packet', full_name='redvox_api_m.EncryptedRedvoxPacketM.packet', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ENCRYPTEDREDVOXPACKETM_HEADER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14321,
  serialized_end=14493,
)


_ACQUISITIONREQUEST = _descriptor.Descriptor(
  name='AcquisitionRequest',
  full_name='redvox_api_m.AcquisitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_token', full_name='redvox_api_m.AcquisitionRequest.auth_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='firebase_token', full_name='redvox_api_m.AcquisitionRequest.firebase_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='redvox_api_m.AcquisitionRequest.checksum', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_encrypted', full_name='redvox_api_m.AcquisitionRequest.is_encrypted', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='redvox_api_m.AcquisitionRequest.payload', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq_id', full_name='redvox_api_m.AcquisitionRequest.seq_id', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14496,
  serialized_end=14633,
)


_ACQUISITIONRESPONSE = _descriptor.Descriptor(
  name='AcquisitionResponse',
  full_name='redvox_api_m.AcquisitionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_type', full_name='redvox_api_m.AcquisitionResponse.response_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='redvox_api_m.AcquisitionResponse.checksum', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='redvox_api_m.AcquisitionResponse.details', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resend', full_name='redvox_api_m.AcquisitionResponse.resend', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq_id', full_name='redvox_api_m.AcquisitionResponse.seq_id', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ACQUISITIONRESPONSE_RESPONSETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14636,
  serialized_end=14881,
)


_SYNCHREQUEST = _descriptor.Descriptor(
  name='SynchRequest',
  full_name='redvox_api_m.SynchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='station_id', full_name='redvox_api_m.SynchRequest.station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='station_uuid', full_name='redvox_api_m.SynchRequest.station_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq_id', full_name='redvox_api_m.SynchRequest.seq_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub_seq_id', full_name='redvox_api_m.SynchRequest.sub_seq_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14883,
  serialized_end=14975,
)


_SYNCHRESPONSE = _descriptor.Descriptor(
  name='SynchResponse',
  full_name='redvox_api_m.SynchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='station_id', full_name='redvox_api_m.SynchResponse.station_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='station_uuid', full_name='redvox_api_m.SynchResponse.station_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq_id', full_name='redvox_api_m.SynchResponse.seq_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub_seq_id', full_name='redvox_api_m.SynchResponse.sub_seq_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recv_ts_us', full_name='redvox_api_m.SynchResponse.recv_ts_us', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_ts_us', full_name='redvox_api_m.SynchResponse.send_ts_us', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14978,
  serialized_end=15111,
)

_REDVOXPACKETM_METADATAENTRY.containing_type = _REDVOXPACKETM
_REDVOXPACKETM_STATIONINFORMATION_METADATAENTRY.containing_type = _REDVOXPACKETM_STATIONINFORMATION
_REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS_METADATAENTRY.containing_type = _REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS
_REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS.fields_by_name['metadata'].message_type = _REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS_METADATAENTRY
_REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS.containing_type = _REDVOXPACKETM_STATIONINFORMATION
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_METADATAENTRY.containing_type = _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.fields_by_name['timestamps'].message_type = _REDVOXPACKETM_TIMINGPAYLOAD
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.fields_by_name['network_type'].enum_type = _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_NETWORKTYPE
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.fields_by_name['cell_service_state'].enum_type = _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_CELLSERVICESTATE
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.fields_by_name['network_strength'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.fields_by_name['temperature'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.fields_by_name['battery'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.fields_by_name['battery_current'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.fields_by_name['available_ram'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.fields_by_name['available_disk'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.fields_by_name['cpu_utilization'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.fields_by_name['power_state'].enum_type = _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_POWERSTATE
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.fields_by_name['wifi_wake_lock'].enum_type = _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_WIFIWAKELOCK
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.fields_by_name['metadata'].message_type = _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_METADATAENTRY
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS.containing_type = _REDVOXPACKETM_STATIONINFORMATION
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_NETWORKTYPE.containing_type = _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_WIFIWAKELOCK.containing_type = _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_CELLSERVICESTATE.containing_type = _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_POWERSTATE.containing_type = _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS
_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_METADATAENTRY.containing_type = _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS
_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS.fields_by_name['audio_sampling_rate'].enum_type = _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSAMPLINGRATE
_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS.fields_by_name['audio_source_tuning'].enum_type = _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSOURCETUNING
_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS.fields_by_name['additional_input_sensors'].enum_type = _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_INPUTSENSOR
_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS.fields_by_name['fft_overlap'].enum_type = _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_FFTOVERLAP
_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS.fields_by_name['metadata'].message_type = _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_METADATAENTRY
_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS.containing_type = _REDVOXPACKETM_STATIONINFORMATION
_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_FFTOVERLAP.containing_type = _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS
_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSAMPLINGRATE.containing_type = _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS
_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_AUDIOSOURCETUNING.containing_type = _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS
_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_INPUTSENSOR.containing_type = _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS
_REDVOXPACKETM_STATIONINFORMATION.fields_by_name['os'].enum_type = _REDVOXPACKETM_STATIONINFORMATION_OSTYPE
_REDVOXPACKETM_STATIONINFORMATION.fields_by_name['app_settings'].message_type = _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS
_REDVOXPACKETM_STATIONINFORMATION.fields_by_name['station_metrics'].message_type = _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS
_REDVOXPACKETM_STATIONINFORMATION.fields_by_name['service_urls'].message_type = _REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS
_REDVOXPACKETM_STATIONINFORMATION.fields_by_name['metadata'].message_type = _REDVOXPACKETM_STATIONINFORMATION_METADATAENTRY
_REDVOXPACKETM_STATIONINFORMATION.containing_type = _REDVOXPACKETM
_REDVOXPACKETM_STATIONINFORMATION_OSTYPE.containing_type = _REDVOXPACKETM_STATIONINFORMATION
_REDVOXPACKETM_TIMINGINFORMATION_METADATAENTRY.containing_type = _REDVOXPACKETM_TIMINGINFORMATION
_REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE_METADATAENTRY.containing_type = _REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE
_REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE.fields_by_name['unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE.fields_by_name['metadata'].message_type = _REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE_METADATAENTRY
_REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE.containing_type = _REDVOXPACKETM_TIMINGINFORMATION
_REDVOXPACKETM_TIMINGINFORMATION.fields_by_name['synch_exchanges'].message_type = _REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE
_REDVOXPACKETM_TIMINGINFORMATION.fields_by_name['score_method'].enum_type = _REDVOXPACKETM_TIMINGINFORMATION_TIMINGSCOREMETHOD
_REDVOXPACKETM_TIMINGINFORMATION.fields_by_name['unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_TIMINGINFORMATION.fields_by_name['metadata'].message_type = _REDVOXPACKETM_TIMINGINFORMATION_METADATAENTRY
_REDVOXPACKETM_TIMINGINFORMATION.containing_type = _REDVOXPACKETM
_REDVOXPACKETM_TIMINGINFORMATION_TIMINGSCOREMETHOD.containing_type = _REDVOXPACKETM_TIMINGINFORMATION
_REDVOXPACKETM_SENSORS_METADATAENTRY.containing_type = _REDVOXPACKETM_SENSORS
_REDVOXPACKETM_SENSORS_AUDIO_METADATAENTRY.containing_type = _REDVOXPACKETM_SENSORS_AUDIO
_REDVOXPACKETM_SENSORS_AUDIO.fields_by_name['samples'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_AUDIO.fields_by_name['metadata'].message_type = _REDVOXPACKETM_SENSORS_AUDIO_METADATAENTRY
_REDVOXPACKETM_SENSORS_AUDIO.containing_type = _REDVOXPACKETM_SENSORS
_REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_METADATAENTRY.containing_type = _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO
_REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO.fields_by_name['audio_codec'].enum_type = _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_AUDIOCODEC
_REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO.fields_by_name['metadata'].message_type = _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_METADATAENTRY
_REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO.containing_type = _REDVOXPACKETM_SENSORS
_REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_AUDIOCODEC.containing_type = _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO
_REDVOXPACKETM_SENSORS_SINGLE_METADATAENTRY.containing_type = _REDVOXPACKETM_SENSORS_SINGLE
_REDVOXPACKETM_SENSORS_SINGLE.fields_by_name['timestamps'].message_type = _REDVOXPACKETM_TIMINGPAYLOAD
_REDVOXPACKETM_SENSORS_SINGLE.fields_by_name['samples'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_SINGLE.fields_by_name['metadata'].message_type = _REDVOXPACKETM_SENSORS_SINGLE_METADATAENTRY
_REDVOXPACKETM_SENSORS_SINGLE.containing_type = _REDVOXPACKETM_SENSORS
_REDVOXPACKETM_SENSORS_LOCATION_METADATAENTRY.containing_type = _REDVOXPACKETM_SENSORS_LOCATION
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_METADATAENTRY.containing_type = _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP_METADATAENTRY.containing_type = _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP.fields_by_name['unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP.fields_by_name['metadata'].message_type = _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP_METADATAENTRY
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP.containing_type = _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['latitude_longitude_timestamp'].message_type = _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['altitude_timestamp'].message_type = _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['speed_timestamp'].message_type = _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['bearing_timestamp'].message_type = _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['latitude_longitude_unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['altitude_unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['speed_unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['bearing_unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['vertical_accuracy_unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['horizontal_accuracy_unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['speed_accuracy_unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['bearing_accuracy_unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['method'].enum_type = _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_LOCATIONSCOREMETHOD
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['location_provider'].enum_type = _REDVOXPACKETM_SENSORS_LOCATION_LOCATIONPROVIDER
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.fields_by_name['metadata'].message_type = _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_METADATAENTRY
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION.containing_type = _REDVOXPACKETM_SENSORS_LOCATION
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_LOCATIONSCOREMETHOD.containing_type = _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['timestamps'].message_type = _REDVOXPACKETM_TIMINGPAYLOAD
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['timestamps_gps'].message_type = _REDVOXPACKETM_TIMINGPAYLOAD
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['latitude_samples'].message_type = _REDVOXPACKETM_DOUBLESAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['longitude_samples'].message_type = _REDVOXPACKETM_DOUBLESAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['altitude_samples'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['speed_samples'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['bearing_samples'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['horizontal_accuracy_samples'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['vertical_accuracy_samples'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['speed_accuracy_samples'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['bearing_accuracy_samples'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['last_best_location'].message_type = _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['overall_best_location'].message_type = _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['location_providers'].enum_type = _REDVOXPACKETM_SENSORS_LOCATION_LOCATIONPROVIDER
_REDVOXPACKETM_SENSORS_LOCATION.fields_by_name['metadata'].message_type = _REDVOXPACKETM_SENSORS_LOCATION_METADATAENTRY
_REDVOXPACKETM_SENSORS_LOCATION.containing_type = _REDVOXPACKETM_SENSORS
_REDVOXPACKETM_SENSORS_LOCATION_LOCATIONPROVIDER.containing_type = _REDVOXPACKETM_SENSORS_LOCATION
_REDVOXPACKETM_SENSORS_XYZ_METADATAENTRY.containing_type = _REDVOXPACKETM_SENSORS_XYZ
_REDVOXPACKETM_SENSORS_XYZ.fields_by_name['timestamps'].message_type = _REDVOXPACKETM_TIMINGPAYLOAD
_REDVOXPACKETM_SENSORS_XYZ.fields_by_name['x_samples'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_XYZ.fields_by_name['y_samples'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_XYZ.fields_by_name['z_samples'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_SENSORS_XYZ.fields_by_name['metadata'].message_type = _REDVOXPACKETM_SENSORS_XYZ_METADATAENTRY
_REDVOXPACKETM_SENSORS_XYZ.containing_type = _REDVOXPACKETM_SENSORS
_REDVOXPACKETM_SENSORS_IMAGE_METADATAENTRY.containing_type = _REDVOXPACKETM_SENSORS_IMAGE
_REDVOXPACKETM_SENSORS_IMAGE.fields_by_name['timestamps'].message_type = _REDVOXPACKETM_TIMINGPAYLOAD
_REDVOXPACKETM_SENSORS_IMAGE.fields_by_name['image_codec'].enum_type = _REDVOXPACKETM_SENSORS_IMAGE_IMAGECODEC
_REDVOXPACKETM_SENSORS_IMAGE.fields_by_name['metadata'].message_type = _REDVOXPACKETM_SENSORS_IMAGE_METADATAENTRY
_REDVOXPACKETM_SENSORS_IMAGE.containing_type = _REDVOXPACKETM_SENSORS
_REDVOXPACKETM_SENSORS_IMAGE_IMAGECODEC.containing_type = _REDVOXPACKETM_SENSORS_IMAGE
_REDVOXPACKETM_SENSORS.fields_by_name['accelerometer'].message_type = _REDVOXPACKETM_SENSORS_XYZ
_REDVOXPACKETM_SENSORS.fields_by_name['ambient_temperature'].message_type = _REDVOXPACKETM_SENSORS_SINGLE
_REDVOXPACKETM_SENSORS.fields_by_name['audio'].message_type = _REDVOXPACKETM_SENSORS_AUDIO
_REDVOXPACKETM_SENSORS.fields_by_name['compressed_audio'].message_type = _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO
_REDVOXPACKETM_SENSORS.fields_by_name['gravity'].message_type = _REDVOXPACKETM_SENSORS_XYZ
_REDVOXPACKETM_SENSORS.fields_by_name['gyroscope'].message_type = _REDVOXPACKETM_SENSORS_XYZ
_REDVOXPACKETM_SENSORS.fields_by_name['image'].message_type = _REDVOXPACKETM_SENSORS_IMAGE
_REDVOXPACKETM_SENSORS.fields_by_name['light'].message_type = _REDVOXPACKETM_SENSORS_SINGLE
_REDVOXPACKETM_SENSORS.fields_by_name['linear_acceleration'].message_type = _REDVOXPACKETM_SENSORS_XYZ
_REDVOXPACKETM_SENSORS.fields_by_name['location'].message_type = _REDVOXPACKETM_SENSORS_LOCATION
_REDVOXPACKETM_SENSORS.fields_by_name['magnetometer'].message_type = _REDVOXPACKETM_SENSORS_XYZ
_REDVOXPACKETM_SENSORS.fields_by_name['orientation'].message_type = _REDVOXPACKETM_SENSORS_XYZ
_REDVOXPACKETM_SENSORS.fields_by_name['pressure'].message_type = _REDVOXPACKETM_SENSORS_SINGLE
_REDVOXPACKETM_SENSORS.fields_by_name['proximity'].message_type = _REDVOXPACKETM_SENSORS_SINGLE
_REDVOXPACKETM_SENSORS.fields_by_name['relative_humidity'].message_type = _REDVOXPACKETM_SENSORS_SINGLE
_REDVOXPACKETM_SENSORS.fields_by_name['rotation_vector'].message_type = _REDVOXPACKETM_SENSORS_XYZ
_REDVOXPACKETM_SENSORS.fields_by_name['metadata'].message_type = _REDVOXPACKETM_SENSORS_METADATAENTRY
_REDVOXPACKETM_SENSORS.containing_type = _REDVOXPACKETM
_REDVOXPACKETM_EVENTSTREAM_METADATAENTRY.containing_type = _REDVOXPACKETM_EVENTSTREAM
_REDVOXPACKETM_EVENTSTREAM_EVENT_STRINGPAYLOADENTRY.containing_type = _REDVOXPACKETM_EVENTSTREAM_EVENT
_REDVOXPACKETM_EVENTSTREAM_EVENT_NUMERICPAYLOADENTRY.containing_type = _REDVOXPACKETM_EVENTSTREAM_EVENT
_REDVOXPACKETM_EVENTSTREAM_EVENT_BOOLEANPAYLOADENTRY.containing_type = _REDVOXPACKETM_EVENTSTREAM_EVENT
_REDVOXPACKETM_EVENTSTREAM_EVENT_BYTEPAYLOADENTRY.containing_type = _REDVOXPACKETM_EVENTSTREAM_EVENT
_REDVOXPACKETM_EVENTSTREAM_EVENT_METADATAENTRY.containing_type = _REDVOXPACKETM_EVENTSTREAM_EVENT
_REDVOXPACKETM_EVENTSTREAM_EVENT.fields_by_name['string_payload'].message_type = _REDVOXPACKETM_EVENTSTREAM_EVENT_STRINGPAYLOADENTRY
_REDVOXPACKETM_EVENTSTREAM_EVENT.fields_by_name['numeric_payload'].message_type = _REDVOXPACKETM_EVENTSTREAM_EVENT_NUMERICPAYLOADENTRY
_REDVOXPACKETM_EVENTSTREAM_EVENT.fields_by_name['boolean_payload'].message_type = _REDVOXPACKETM_EVENTSTREAM_EVENT_BOOLEANPAYLOADENTRY
_REDVOXPACKETM_EVENTSTREAM_EVENT.fields_by_name['byte_payload'].message_type = _REDVOXPACKETM_EVENTSTREAM_EVENT_BYTEPAYLOADENTRY
_REDVOXPACKETM_EVENTSTREAM_EVENT.fields_by_name['metadata'].message_type = _REDVOXPACKETM_EVENTSTREAM_EVENT_METADATAENTRY
_REDVOXPACKETM_EVENTSTREAM_EVENT.containing_type = _REDVOXPACKETM_EVENTSTREAM
_REDVOXPACKETM_EVENTSTREAM.fields_by_name['timestamps'].message_type = _REDVOXPACKETM_TIMINGPAYLOAD
_REDVOXPACKETM_EVENTSTREAM.fields_by_name['events'].message_type = _REDVOXPACKETM_EVENTSTREAM_EVENT
_REDVOXPACKETM_EVENTSTREAM.fields_by_name['metadata'].message_type = _REDVOXPACKETM_EVENTSTREAM_METADATAENTRY
_REDVOXPACKETM_EVENTSTREAM.containing_type = _REDVOXPACKETM
_REDVOXPACKETM_SAMPLEPAYLOAD_METADATAENTRY.containing_type = _REDVOXPACKETM_SAMPLEPAYLOAD
_REDVOXPACKETM_SAMPLEPAYLOAD.fields_by_name['unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_SAMPLEPAYLOAD.fields_by_name['value_statistics'].message_type = _REDVOXPACKETM_SUMMARYSTATISTICS
_REDVOXPACKETM_SAMPLEPAYLOAD.fields_by_name['metadata'].message_type = _REDVOXPACKETM_SAMPLEPAYLOAD_METADATAENTRY
_REDVOXPACKETM_SAMPLEPAYLOAD.containing_type = _REDVOXPACKETM
_REDVOXPACKETM_DOUBLESAMPLEPAYLOAD_METADATAENTRY.containing_type = _REDVOXPACKETM_DOUBLESAMPLEPAYLOAD
_REDVOXPACKETM_DOUBLESAMPLEPAYLOAD.fields_by_name['unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_DOUBLESAMPLEPAYLOAD.fields_by_name['value_statistics'].message_type = _REDVOXPACKETM_SUMMARYSTATISTICS
_REDVOXPACKETM_DOUBLESAMPLEPAYLOAD.fields_by_name['metadata'].message_type = _REDVOXPACKETM_DOUBLESAMPLEPAYLOAD_METADATAENTRY
_REDVOXPACKETM_DOUBLESAMPLEPAYLOAD.containing_type = _REDVOXPACKETM
_REDVOXPACKETM_TIMINGPAYLOAD_METADATAENTRY.containing_type = _REDVOXPACKETM_TIMINGPAYLOAD
_REDVOXPACKETM_TIMINGPAYLOAD.fields_by_name['unit'].enum_type = _REDVOXPACKETM_UNIT
_REDVOXPACKETM_TIMINGPAYLOAD.fields_by_name['timestamp_statistics'].message_type = _REDVOXPACKETM_SUMMARYSTATISTICS
_REDVOXPACKETM_TIMINGPAYLOAD.fields_by_name['metadata'].message_type = _REDVOXPACKETM_TIMINGPAYLOAD_METADATAENTRY
_REDVOXPACKETM_TIMINGPAYLOAD.containing_type = _REDVOXPACKETM
_REDVOXPACKETM_SUMMARYSTATISTICS_METADATAENTRY.containing_type = _REDVOXPACKETM_SUMMARYSTATISTICS
_REDVOXPACKETM_SUMMARYSTATISTICS.fields_by_name['metadata'].message_type = _REDVOXPACKETM_SUMMARYSTATISTICS_METADATAENTRY
_REDVOXPACKETM_SUMMARYSTATISTICS.containing_type = _REDVOXPACKETM
_REDVOXPACKETM.fields_by_name['station_information'].message_type = _REDVOXPACKETM_STATIONINFORMATION
_REDVOXPACKETM.fields_by_name['timing_information'].message_type = _REDVOXPACKETM_TIMINGINFORMATION
_REDVOXPACKETM.fields_by_name['sensors'].message_type = _REDVOXPACKETM_SENSORS
_REDVOXPACKETM.fields_by_name['event_streams'].message_type = _REDVOXPACKETM_EVENTSTREAM
_REDVOXPACKETM.fields_by_name['metadata'].message_type = _REDVOXPACKETM_METADATAENTRY
_REDVOXPACKETM_UNIT.containing_type = _REDVOXPACKETM
_ENCRYPTEDREDVOXPACKETM_HEADER.containing_type = _ENCRYPTEDREDVOXPACKETM
_ACQUISITIONRESPONSE.fields_by_name['response_type'].enum_type = _ACQUISITIONRESPONSE_RESPONSETYPE
_ACQUISITIONRESPONSE_RESPONSETYPE.containing_type = _ACQUISITIONRESPONSE
DESCRIPTOR.message_types_by_name['RedvoxPacketM'] = _REDVOXPACKETM
DESCRIPTOR.message_types_by_name['EncryptedRedvoxPacketM'] = _ENCRYPTEDREDVOXPACKETM
DESCRIPTOR.message_types_by_name['AcquisitionRequest'] = _ACQUISITIONREQUEST
DESCRIPTOR.message_types_by_name['AcquisitionResponse'] = _ACQUISITIONRESPONSE
DESCRIPTOR.message_types_by_name['SynchRequest'] = _SYNCHREQUEST
DESCRIPTOR.message_types_by_name['SynchResponse'] = _SYNCHRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RedvoxPacketM = _reflection.GeneratedProtocolMessageType('RedvoxPacketM', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _REDVOXPACKETM_METADATAENTRY,
    '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
    # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.MetadataEntry)
    })
  ,

  'StationInformation' : _reflection.GeneratedProtocolMessageType('StationInformation', (_message.Message,), {

    'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
      'DESCRIPTOR' : _REDVOXPACKETM_STATIONINFORMATION_METADATAENTRY,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.StationInformation.MetadataEntry)
      })
    ,

    'ServiceUrls' : _reflection.GeneratedProtocolMessageType('ServiceUrls', (_message.Message,), {

      'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS_METADATAENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls.MetadataEntry)
        })
      ,
      'DESCRIPTOR' : _REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.StationInformation.ServiceUrls)
      })
    ,

    'StationMetrics' : _reflection.GeneratedProtocolMessageType('StationMetrics', (_message.Message,), {

      'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_METADATAENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics.MetadataEntry)
        })
      ,
      'DESCRIPTOR' : _REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.StationInformation.StationMetrics)
      })
    ,

    'AppSettings' : _reflection.GeneratedProtocolMessageType('AppSettings', (_message.Message,), {

      'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_METADATAENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.StationInformation.AppSettings.MetadataEntry)
        })
      ,
      'DESCRIPTOR' : _REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.StationInformation.AppSettings)
      })
    ,
    'DESCRIPTOR' : _REDVOXPACKETM_STATIONINFORMATION,
    '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
    # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.StationInformation)
    })
  ,

  'TimingInformation' : _reflection.GeneratedProtocolMessageType('TimingInformation', (_message.Message,), {

    'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
      'DESCRIPTOR' : _REDVOXPACKETM_TIMINGINFORMATION_METADATAENTRY,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.TimingInformation.MetadataEntry)
      })
    ,

    'SynchExchange' : _reflection.GeneratedProtocolMessageType('SynchExchange', (_message.Message,), {

      'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE_METADATAENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange.MetadataEntry)
        })
      ,
      'DESCRIPTOR' : _REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.TimingInformation.SynchExchange)
      })
    ,
    'DESCRIPTOR' : _REDVOXPACKETM_TIMINGINFORMATION,
    '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
    # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.TimingInformation)
    })
  ,

  'Sensors' : _reflection.GeneratedProtocolMessageType('Sensors', (_message.Message,), {

    'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
      'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_METADATAENTRY,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.MetadataEntry)
      })
    ,

    'Audio' : _reflection.GeneratedProtocolMessageType('Audio', (_message.Message,), {

      'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_AUDIO_METADATAENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Audio.MetadataEntry)
        })
      ,
      'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_AUDIO,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Audio)
      })
    ,

    'CompressedAudio' : _reflection.GeneratedProtocolMessageType('CompressedAudio', (_message.Message,), {

      'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_METADATAENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio.MetadataEntry)
        })
      ,
      'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.CompressedAudio)
      })
    ,

    'Single' : _reflection.GeneratedProtocolMessageType('Single', (_message.Message,), {

      'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_SINGLE_METADATAENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Single.MetadataEntry)
        })
      ,
      'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_SINGLE,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Single)
      })
    ,

    'Location' : _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {

      'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_LOCATION_METADATAENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Location.MetadataEntry)
        })
      ,

      'BestLocation' : _reflection.GeneratedProtocolMessageType('BestLocation', (_message.Message,), {

        'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
          'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_METADATAENTRY,
          '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
          # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.MetadataEntry)
          })
        ,

        'BestTimestamp' : _reflection.GeneratedProtocolMessageType('BestTimestamp', (_message.Message,), {

          'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
            'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP_METADATAENTRY,
            '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
            # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp.MetadataEntry)
            })
          ,
          'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP,
          '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
          # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp)
          })
        ,
        'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Location.BestLocation)
        })
      ,
      'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_LOCATION,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Location)
      })
    ,

    'Xyz' : _reflection.GeneratedProtocolMessageType('Xyz', (_message.Message,), {

      'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_XYZ_METADATAENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Xyz.MetadataEntry)
        })
      ,
      'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_XYZ,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Xyz)
      })
    ,

    'Image' : _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {

      'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_IMAGE_METADATAENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Image.MetadataEntry)
        })
      ,
      'DESCRIPTOR' : _REDVOXPACKETM_SENSORS_IMAGE,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors.Image)
      })
    ,
    'DESCRIPTOR' : _REDVOXPACKETM_SENSORS,
    '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
    # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.Sensors)
    })
  ,

  'EventStream' : _reflection.GeneratedProtocolMessageType('EventStream', (_message.Message,), {

    'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
      'DESCRIPTOR' : _REDVOXPACKETM_EVENTSTREAM_METADATAENTRY,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.EventStream.MetadataEntry)
      })
    ,

    'Event' : _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {

      'StringPayloadEntry' : _reflection.GeneratedProtocolMessageType('StringPayloadEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_EVENTSTREAM_EVENT_STRINGPAYLOADENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.EventStream.Event.StringPayloadEntry)
        })
      ,

      'NumericPayloadEntry' : _reflection.GeneratedProtocolMessageType('NumericPayloadEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_EVENTSTREAM_EVENT_NUMERICPAYLOADENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.EventStream.Event.NumericPayloadEntry)
        })
      ,

      'BooleanPayloadEntry' : _reflection.GeneratedProtocolMessageType('BooleanPayloadEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_EVENTSTREAM_EVENT_BOOLEANPAYLOADENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.EventStream.Event.BooleanPayloadEntry)
        })
      ,

      'BytePayloadEntry' : _reflection.GeneratedProtocolMessageType('BytePayloadEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_EVENTSTREAM_EVENT_BYTEPAYLOADENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.EventStream.Event.BytePayloadEntry)
        })
      ,

      'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
        'DESCRIPTOR' : _REDVOXPACKETM_EVENTSTREAM_EVENT_METADATAENTRY,
        '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
        # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.EventStream.Event.MetadataEntry)
        })
      ,
      'DESCRIPTOR' : _REDVOXPACKETM_EVENTSTREAM_EVENT,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.EventStream.Event)
      })
    ,
    'DESCRIPTOR' : _REDVOXPACKETM_EVENTSTREAM,
    '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
    # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.EventStream)
    })
  ,

  'SamplePayload' : _reflection.GeneratedProtocolMessageType('SamplePayload', (_message.Message,), {

    'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
      'DESCRIPTOR' : _REDVOXPACKETM_SAMPLEPAYLOAD_METADATAENTRY,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.SamplePayload.MetadataEntry)
      })
    ,
    'DESCRIPTOR' : _REDVOXPACKETM_SAMPLEPAYLOAD,
    '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
    # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.SamplePayload)
    })
  ,

  'DoubleSamplePayload' : _reflection.GeneratedProtocolMessageType('DoubleSamplePayload', (_message.Message,), {

    'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
      'DESCRIPTOR' : _REDVOXPACKETM_DOUBLESAMPLEPAYLOAD_METADATAENTRY,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.DoubleSamplePayload.MetadataEntry)
      })
    ,
    'DESCRIPTOR' : _REDVOXPACKETM_DOUBLESAMPLEPAYLOAD,
    '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
    # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.DoubleSamplePayload)
    })
  ,

  'TimingPayload' : _reflection.GeneratedProtocolMessageType('TimingPayload', (_message.Message,), {

    'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
      'DESCRIPTOR' : _REDVOXPACKETM_TIMINGPAYLOAD_METADATAENTRY,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.TimingPayload.MetadataEntry)
      })
    ,
    'DESCRIPTOR' : _REDVOXPACKETM_TIMINGPAYLOAD,
    '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
    # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.TimingPayload)
    })
  ,

  'SummaryStatistics' : _reflection.GeneratedProtocolMessageType('SummaryStatistics', (_message.Message,), {

    'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
      'DESCRIPTOR' : _REDVOXPACKETM_SUMMARYSTATISTICS_METADATAENTRY,
      '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
      # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.SummaryStatistics.MetadataEntry)
      })
    ,
    'DESCRIPTOR' : _REDVOXPACKETM_SUMMARYSTATISTICS,
    '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
    # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM.SummaryStatistics)
    })
  ,
  'DESCRIPTOR' : _REDVOXPACKETM,
  '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
  # @@protoc_insertion_point(class_scope:redvox_api_m.RedvoxPacketM)
  })
_sym_db.RegisterMessage(RedvoxPacketM)
_sym_db.RegisterMessage(RedvoxPacketM.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.StationInformation)
_sym_db.RegisterMessage(RedvoxPacketM.StationInformation.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.StationInformation.ServiceUrls)
_sym_db.RegisterMessage(RedvoxPacketM.StationInformation.ServiceUrls.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.StationInformation.StationMetrics)
_sym_db.RegisterMessage(RedvoxPacketM.StationInformation.StationMetrics.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.StationInformation.AppSettings)
_sym_db.RegisterMessage(RedvoxPacketM.StationInformation.AppSettings.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.TimingInformation)
_sym_db.RegisterMessage(RedvoxPacketM.TimingInformation.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.TimingInformation.SynchExchange)
_sym_db.RegisterMessage(RedvoxPacketM.TimingInformation.SynchExchange.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Audio)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Audio.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.CompressedAudio)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.CompressedAudio.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Single)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Single.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Location)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Location.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Location.BestLocation)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Location.BestLocation.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Location.BestLocation.BestTimestamp.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Xyz)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Xyz.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Image)
_sym_db.RegisterMessage(RedvoxPacketM.Sensors.Image.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.EventStream)
_sym_db.RegisterMessage(RedvoxPacketM.EventStream.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.EventStream.Event)
_sym_db.RegisterMessage(RedvoxPacketM.EventStream.Event.StringPayloadEntry)
_sym_db.RegisterMessage(RedvoxPacketM.EventStream.Event.NumericPayloadEntry)
_sym_db.RegisterMessage(RedvoxPacketM.EventStream.Event.BooleanPayloadEntry)
_sym_db.RegisterMessage(RedvoxPacketM.EventStream.Event.BytePayloadEntry)
_sym_db.RegisterMessage(RedvoxPacketM.EventStream.Event.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.SamplePayload)
_sym_db.RegisterMessage(RedvoxPacketM.SamplePayload.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.DoubleSamplePayload)
_sym_db.RegisterMessage(RedvoxPacketM.DoubleSamplePayload.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.TimingPayload)
_sym_db.RegisterMessage(RedvoxPacketM.TimingPayload.MetadataEntry)
_sym_db.RegisterMessage(RedvoxPacketM.SummaryStatistics)
_sym_db.RegisterMessage(RedvoxPacketM.SummaryStatistics.MetadataEntry)

EncryptedRedvoxPacketM = _reflection.GeneratedProtocolMessageType('EncryptedRedvoxPacketM', (_message.Message,), {

  'Header' : _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
    'DESCRIPTOR' : _ENCRYPTEDREDVOXPACKETM_HEADER,
    '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
    # @@protoc_insertion_point(class_scope:redvox_api_m.EncryptedRedvoxPacketM.Header)
    })
  ,
  'DESCRIPTOR' : _ENCRYPTEDREDVOXPACKETM,
  '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
  # @@protoc_insertion_point(class_scope:redvox_api_m.EncryptedRedvoxPacketM)
  })
_sym_db.RegisterMessage(EncryptedRedvoxPacketM)
_sym_db.RegisterMessage(EncryptedRedvoxPacketM.Header)

AcquisitionRequest = _reflection.GeneratedProtocolMessageType('AcquisitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACQUISITIONREQUEST,
  '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
  # @@protoc_insertion_point(class_scope:redvox_api_m.AcquisitionRequest)
  })
_sym_db.RegisterMessage(AcquisitionRequest)

AcquisitionResponse = _reflection.GeneratedProtocolMessageType('AcquisitionResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACQUISITIONRESPONSE,
  '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
  # @@protoc_insertion_point(class_scope:redvox_api_m.AcquisitionResponse)
  })
_sym_db.RegisterMessage(AcquisitionResponse)

SynchRequest = _reflection.GeneratedProtocolMessageType('SynchRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYNCHREQUEST,
  '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
  # @@protoc_insertion_point(class_scope:redvox_api_m.SynchRequest)
  })
_sym_db.RegisterMessage(SynchRequest)

SynchResponse = _reflection.GeneratedProtocolMessageType('SynchResponse', (_message.Message,), {
  'DESCRIPTOR' : _SYNCHRESPONSE,
  '__module__' : 'src.redvox_api_m.redvox_api_m_pb2'
  # @@protoc_insertion_point(class_scope:redvox_api_m.SynchResponse)
  })
_sym_db.RegisterMessage(SynchResponse)


DESCRIPTOR._options = None
_REDVOXPACKETM_METADATAENTRY._options = None
_REDVOXPACKETM_STATIONINFORMATION_METADATAENTRY._options = None
_REDVOXPACKETM_STATIONINFORMATION_SERVICEURLS_METADATAENTRY._options = None
_REDVOXPACKETM_STATIONINFORMATION_STATIONMETRICS_METADATAENTRY._options = None
_REDVOXPACKETM_STATIONINFORMATION_APPSETTINGS_METADATAENTRY._options = None
_REDVOXPACKETM_TIMINGINFORMATION_METADATAENTRY._options = None
_REDVOXPACKETM_TIMINGINFORMATION_SYNCHEXCHANGE_METADATAENTRY._options = None
_REDVOXPACKETM_SENSORS_METADATAENTRY._options = None
_REDVOXPACKETM_SENSORS_AUDIO_METADATAENTRY._options = None
_REDVOXPACKETM_SENSORS_COMPRESSEDAUDIO_METADATAENTRY._options = None
_REDVOXPACKETM_SENSORS_SINGLE_METADATAENTRY._options = None
_REDVOXPACKETM_SENSORS_LOCATION_METADATAENTRY._options = None
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_METADATAENTRY._options = None
_REDVOXPACKETM_SENSORS_LOCATION_BESTLOCATION_BESTTIMESTAMP_METADATAENTRY._options = None
_REDVOXPACKETM_SENSORS_XYZ_METADATAENTRY._options = None
_REDVOXPACKETM_SENSORS_IMAGE_METADATAENTRY._options = None
_REDVOXPACKETM_EVENTSTREAM_METADATAENTRY._options = None
_REDVOXPACKETM_EVENTSTREAM_EVENT_STRINGPAYLOADENTRY._options = None
_REDVOXPACKETM_EVENTSTREAM_EVENT_NUMERICPAYLOADENTRY._options = None
_REDVOXPACKETM_EVENTSTREAM_EVENT_BOOLEANPAYLOADENTRY._options = None
_REDVOXPACKETM_EVENTSTREAM_EVENT_BYTEPAYLOADENTRY._options = None
_REDVOXPACKETM_EVENTSTREAM_EVENT_METADATAENTRY._options = None
_REDVOXPACKETM_SAMPLEPAYLOAD_METADATAENTRY._options = None
_REDVOXPACKETM_DOUBLESAMPLEPAYLOAD_METADATAENTRY._options = None
_REDVOXPACKETM_TIMINGPAYLOAD_METADATAENTRY._options = None
_REDVOXPACKETM_SUMMARYSTATISTICS_METADATAENTRY._options = None
# @@protoc_insertion_point(module_scope)
